aboutsummaryrefslogtreecommitdiff
path: root/src/crypto/internal
diff options
context:
space:
mode:
Diffstat (limited to 'src/crypto/internal')
-rw-r--r--src/crypto/internal/fips140only/fips140only.go8
1 files changed, 5 insertions, 3 deletions
diff --git a/src/crypto/internal/fips140only/fips140only.go b/src/crypto/internal/fips140only/fips140only.go
index 147877a34f..1b0a4be6ba 100644
--- a/src/crypto/internal/fips140only/fips140only.go
+++ b/src/crypto/internal/fips140only/fips140only.go
@@ -5,18 +5,20 @@
package fips140only
import (
+ "crypto/fips140"
"crypto/internal/fips140/drbg"
"crypto/internal/fips140/sha256"
"crypto/internal/fips140/sha3"
"crypto/internal/fips140/sha512"
"hash"
- "internal/godebug"
"io"
)
// Enabled reports whether FIPS 140-only mode is enabled, in which non-approved
// cryptography returns an error or panics.
-var Enabled = godebug.New("fips140").Value() == "only"
+func Enforced() bool {
+ return fips140.Enforced()
+}
func ApprovedHash(h hash.Hash) bool {
switch h.(type) {
@@ -5,18 +5,20 @@
"io"
)
-// Enabled reports whether FIPS 140-only mode is enabled, in which non-approved
+// Enforced reports whether FIPS 140-only mode is enabled and enforced, in which non-approved
// cryptography returns an error or panics.